@@ -5,15 +5,15 @@
  * Copyright (C) 2012 Igalia S.L.
  */
 
-#ifndef SOUP_VERSION_H
-#define SOUP_VERSION_H
+#ifndef __SOUP_VERSION_H__
+#define __SOUP_VERSION_H__
 
 #include <glib.h>
 
 G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (2)
-#define SOUP_MINOR_VERSION (62)
+#define SOUP_MINOR_VERSION (66)
 #define SOUP_MICRO_VERSION (3)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
@@ -66,6 +66,7 @@ G_BEGIN_DECLS
 #define SOUP_VERSION_2_56 (G_ENCODE_VERSION (2, 56))
 #define SOUP_VERSION_2_58 (G_ENCODE_VERSION (2, 58))
 #define SOUP_VERSION_2_62 (G_ENCODE_VERSION (2, 62))
+#define SOUP_VERSION_2_66 (G_ENCODE_VERSION (2, 66))
 
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
@@ -374,6 +375,20 @@ G_BEGIN_DECLS
 # define SOUP_AVAILABLE_IN_2_62                 _SOUP_EXTERN
 #endif
 
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_2_66
+# define SOUP_DEPRECATED_IN_2_66                G_DEPRECATED
+# define SOUP_DEPRECATED_IN_2_66_FOR(f)         G_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_2_66
+# define SOUP_DEPRECATED_IN_2_66_FOR(f)
+#endif
+
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_2_66
+# define SOUP_AVAILABLE_IN_2_66                 G_UNAVAILABLE(2, 66) _SOUP_EXTERN
+#else
+# define SOUP_AVAILABLE_IN_2_66                 _SOUP_EXTERN
+#endif
+
 SOUP_AVAILABLE_IN_2_42
 guint    soup_get_major_version (void);
 
@@ -390,4 +405,4 @@ gboolean soup_check_version     (guint major,
 
 G_END_DECLS
 
-#endif /* SOUP_VERSION_H */
+#endif /* __SOUP_VERSION_H__ */
